import 'dart:async';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

typedef void FlutterPanoramaViewCallback(PanoramaViewController controller);

class PanoramaViewController{

  PanoramaViewController(int id) : _channel = new MethodChannel("flutter.9life.vn/img360viewer");

  final MethodChannel _channel;
  String _url="";
  String get url => _url;

  Future<void> init() async {
    return _channel.invokeMethod("loadImage");
  }

  void setUrl(String url){
    _url = url;
  }

  Future<void> loadImage(String image) async{
    return _channel.invokeMethod("loadImage",image);
  }
}

class PanoramaView extends StatefulWidget {

  final FlutterPanoramaViewCallback onPanoramaViewCreated;
  final String assets;
  final String url;
  const PanoramaView({
    Key key,
    this.assets,
    this.url,
    this.onPanoramaViewCreated,
  }) : super(key: key);
  @override
  State<StatefulWidget> createState()=> _PanoramaStateView();
}

class _PanoramaStateView extends State<PanoramaView> {

  PanoramaViewController _control;

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Container(
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
          child: AndroidView(
          key: UniqueKey(),
          viewType: 'flutter.9life.vn/img360viewer',
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    }
    if (defaultTargetPlatform == TargetPlatform.iOS) {
      return Container(
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
        child: UiKitView(
          key: UniqueKey(),
          viewType: 'flutter.9life.vn/img360viewer',
          onPlatformViewCreated: _onPlatformViewCreated,
        ),
      );
    }
    return Text(
        '$defaultTargetPlatform is not yet supported by the text_view plugin');
  }

  void _onPlatformViewCreated(int id) {
    _control = new PanoramaViewController(id);
    if (widget.onPanoramaViewCreated == null) {
      return;
    }
    _control.setUrl(widget.url);
    widget.onPanoramaViewCreated(_control);
  }

  double size(BuildContext context, double dimens) {
    if (MediaQuery
        .of(context)
        .devicePixelRatio == 3) {
      return dimens;
    }
    return dimens * MediaQuery
        .of(context)
        .devicePixelRatio / 3;
  }
}
